==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/catalan/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Llista Actual d'&Agrave;lbums";
$TEXT002="Enviar &Agrave;lbum";
$TEXT003="T&iacute;tol de l'&Agrave;lbum";
$TEXT004="Descripci&oacute;";
$TEXT005="Fotos";
$TEXT006="Autor";
$TEXT007="Data";
$TEXT008="Anterior";
$TEXT009="Seg&uuml;ent";
$TEXT010="Total";
$TEXT011="Secci&oacute; d'&Agrave;lbum de Fotos";
$TEXT012="T&iacute;tol de l'&Agrave;lbum: ";
$TEXT013="Editar &Agrave;lbum: ";
$TEXT014="alta";
$TEXT015="mitja";
$TEXT016="baixa";
$TEXT017="Eliminar les Seleccionades";
$TEXT018="Editar";
$TEXT019="Afegir Fotos";
$TEXT020="Esborrar &Agrave;lbum";
$TEXT021="No tens els permisos suficients per editar les propietats de l'&aacute;lbum seleccionat !";
$TEXT022="Data d'enviament:";
$TEXT023="Opcional";
$TEXT024="Introdueix una breu descripci&oacute; de l'&aacute;lbum de fotos (max. 255 carac.)";
$TEXT025="Selecciona qui pot veure'l: ";
$TEXT026="(Opci&oacute; per defecte: Tothom)";
$TEXT027="Tothom";
$TEXT028="Usuaris registrats";
$TEXT029="Nom&eacute;s una llista d'usuaris registrats";
$TEXT030="(Polsa la tecla -Ctrl- per seleccionar varis usuaris simultani&agrave;ment)";
$TEXT031="Selecciona qui pot editar-lo i afegir o esborrar fotos: ";
$TEXT032="Seg&uuml;ent Pas: Pujar les Fotos";
$TEXT033="Publicar";
$TEXT034="Registre d'un nou &aacute;lbum de fotos";
$TEXT035="Pas 2: Selecci&oacute; de Fotos";
$TEXT036="Selecciona l'&aacute;lbum al qual cols afegir les fotos:";

$TEXT037="Afegeix les fotos d'una en una y polsa a (Pas Seg&uuml;ent) quan hagis acabat.<br>".
         "No et preocupis si vols afegir m&eacute;s fotos, ja que podr&agrave;s afegir les que".
         "vulguis un cop que l'&aacute;lbum ja estigui publicat.";

$TEXT038="Selecciona una foto:";
$TEXT039="Descripci&oacute; de la Foto:";
$TEXT040="Llista actual de fotos per aquest &aacute;lbum";
$TEXT041="nombre de fotos";
$TEXT042="Pas Seg&uuml;ent: Confirmaci&oacute;";
$TEXT043="No tens suficientes permisos per afegir noves fotos a aquest &aacute;lbum !";
$TEXT044="Alta d'un nou &aacute;lbum de fotos";
$TEXT045="&Uacute;ltim Pas";
$TEXT046="Enhorabona!";
$TEXT047="Totes les  dades de l'&aacute;lbum i les fotos d'aquest, s'han rebut correctament.";

$TEXT048="L'&aacute;lbum s'ha publicat correctament.<br><br>".
         "Els usuaris seleccionats podr&agrave;n veure'l i modificar-lo.";

$TEXT049="La seg&uuml;ent llista d'&aacute;lbums estan pendents de la teva aprovaci&oacute;. ".
         "Si pot veure aquesta llista es que disposes dels privilegis suficients per fer-ho.<br>".
         "Pots esborrar directament un &aacute;lbum polsant a sobre de la opci&oacute; Esborrar.<br>".
         "En cas contrari, polsa sobre el t&iacute;tol de la not&iacute;cia que vulguis editar i/o publicar.";

$TEXT050="Esborrar";
$TEXT051="Id.&Aacute;lbum";
$TEXT052="T&iacute;tol";
$TEXT053="Data";
$TEXT054="No hi han albums pendents de publicar.";
$TEXT055="Esborrant &Aacute;lbum";
$TEXT056="Compte, assegurat abans de continuar!";
$TEXT057="La seg&uuml;ent llista de fitxers s'esborraran:";
$TEXT059="No disposes de privilegis suficients per esborrar aquest &aacute;lbum!";

$TEXT060="Nom&eacute;s els usuaris enregistrats poden eliminar &agrave;lbums.<br>".
         "Encara que l'autor don&eacute;s acc&eacute;s complet al teu &acute;lbum de fotos.";
?>

==> homesitemaker-v0.4.3.tar.gz: homesitemaker/includes/languages/catalan/homesite-album.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$TEXT001="Llista Actual d'&Agrave;lbums";
$TEXT002="Enviar &Agrave;lbum";
$TEXT003="T&iacute;tol de l'&Agrave;lbum";
$TEXT004="Descripci&oacute;";
$TEXT005="Fotos";
$TEXT006="Autor";
$TEXT007="Data";
$TEXT008="Anterior";
$TEXT009="Seg&uuml;ent";
$TEXT010="Total";
$TEXT011="Secci&oacute; d'&Agrave;lbum de Fotos";
$TEXT012="T&iacute;tol de l'&Agrave;lbum: ";
$TEXT013="Editar &Agrave;lbum: ";
$TEXT014="alta";
$TEXT015="mitja";
$TEXT016="baixa";
$TEXT017="Eliminar les Seleccionades";
$TEXT018="Editar";
$TEXT019="Afegir Fotos";
$TEXT020="Esborrar &Agrave;lbum";
$TEXT021="No tens els permisos suficients per editar les propietats de l'&aacute;lbum seleccionat !";
$TEXT022="Data d'enviament:";
$TEXT023="Opcional";
$TEXT024="Introdueix una breu descripci&oacute; de l'&aacute;lbum de fotos (max. 255 carac.)";
$TEXT025="Selecciona qui pot veure'l: ";
$TEXT026="(Opci&oacute; per defecte: Tothom)";
$TEXT027="Tothom";
$TEXT028="Usuaris registrats";
$TEXT029="Nom&eacute;s una llista d'usuaris registrats";
$TEXT030="(Polsa la tecla -Ctrl- per seleccionar varis usuaris simultani&agrave;ment)";
$TEXT031="Selecciona qui pot editar-lo i afegir o esborrar fotos: ";
$TEXT032="Seg&uuml;ent Pas: Pujar les Fotos";
$TEXT033="Publicar";
$TEXT034="Registre d'un nou &aacute;lbum de fotos";
$TEXT035="Pas 2: Selecci&oacute; de Fotos";
$TEXT036="Selecciona l'&aacute;lbum al qual cols afegir les fotos:";

$TEXT037="Afegeix les fotos d'una en una y polsa a (Pas Seg&uuml;ent) quan hagis acabat.<br>".
         "No et preocupis si vols afegir m&eacute;s fotos, ja que podr&agrave;s afegir les que".
         "vulguis un cop que l'&aacute;lbum ja estigui publicat.";

$TEXT038="Selecciona una foto:";
$TEXT039="Descripci&oacute; de la Foto:";
$TEXT040="Llista actual de fotos per aquest &aacute;lbum";
$TEXT041="nombre de fotos";
$TEXT042="Pas Seg&uuml;ent: Confirmaci&oacute;";
$TEXT043="No tens suficientes permisos per afegir noves fotos a aquest &aacute;lbum !";
$TEXT044="Alta d'un nou &aacute;lbum de fotos";
$TEXT045="&Uacute;ltim Pas";
$TEXT046="Enhorabona!";
$TEXT047="Totes les  dades de l'&aacute;lbum i les fotos d'aquest, s'han rebut correctament.";

$TEXT048="L'&aacute;lbum s'ha publicat correctament.<br><br>".
         "Els usuaris seleccionats podr&agrave;n veure'l i modificar-lo.";

$TEXT049="La seg&uuml;ent llista d'&aacute;lbums estan pendents de la teva aprovaci&oacute;. ".
         "Si pot veure aquesta llista es que disposes dels privilegis suficients per fer-ho.<br>".
         "Pots esborrar directament un &aacute;lbum polsant a sobre de la opci&oacute; Esborrar.<br>".
         "En cas contrari, polsa sobre el t&iacute;tol de la not&iacute;cia que vulguis editar i/o publicar.";

$TEXT050="Esborrar";
$TEXT051="Id.&Aacute;lbum";
$TEXT052="T&iacute;tol";
$TEXT053="Data";
$TEXT054="No hi han albums pendents de publicar.";
$TEXT055="Esborrant &Aacute;lbum";
$TEXT056="Compte, assegurat abans de continuar!";
$TEXT057="La seg&uuml;ent llista de fitxers s'esborraran:";
$TEXT059="No disposes de privilegis suficients per esborrar aquest &aacute;lbum!";

$TEXT060="Nom&eacute;s els usuaris enregistrats poden eliminar &agrave;lbums.<br>".
         "Encara que l'autor don&eacute;s acc&eacute;s complet al teu &acute;lbum de fotos.";
$TEXT061="<br>No tens permisos suficients per publicar albums pendents!<br><br>".
         "Si vols ser Edior, envia un correu al administrador de la web.<br>&nbsp;";
$TEXT062="Editar Seleccionats";
$TEXT063="Editar Comentaris";
$TEXT064="Aplicar Cambis";
$TEXT065="Els seg&uuml;ents commentaris ser&aacuten modificats:";
$TEXT066="No has selleccionat cap fotografia!";
?>
